@@ -1,11 +1,12 @@
 /* AstroChart.m
  * The circular Astrology chart
  *
- * Copyright (C) 1998-2010 by vhf interservice GmbH
+ * Copyright (C) 1998-2011 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
- * modified: 2010-01-17 (-radix:...: scale chart to fit window)
+ * modified: 2011-04-22 (modulo chart)
+ *           2010-01-17 (-radix:...: scale chart to fit window)
  *           2009-04-01 (radix: no date: draw composite only)
  *
  * This program is free software; you can redistribute it and/or
@@ -71,6 +72,7 @@
 {
     [super init];
     view = [aView retain];
+    divider = 1;
     return self;
 }
 - (void)setView:(id)aView
@@ -83,6 +85,21 @@
     return view;
 }
 
+- (void)setDivider:(int)div
+{
+    divider = div;
+}
+- (void)setObjDividers:(NSDictionary*)dict
+{
+    [dividerDict release];
+    dividerDict = [dict retain];
+}
+
+static double modulo(double num, double denom)
+{
+    return (num - floor(num / denom) * denom);
+}
+
 /* angle deg1 - deg2 */
 static NSString *formAngle(float deg1, float deg2)
 {   float	a = angle(deg1, deg2);
@@ -407,6 +424,27 @@ typedef enum
     [layer addObject:group];
 }
 
+/* experimental
+ * created: 2011-04-24
+ */
+- (float)moduloAngle:(float)angle forObject:(NSString*)planet
+{
+    if ( dividerDict )
+    {   //NSString    *sym = [symbols objectForKey:planet];
+        int         ix   = [[ephemeris objectNames] indexOfObject:planet];
+        NSString    *sym = [[ephemeris objectSymbols] objectAtIndex:ix];
+        BOOL        scale= [dividerDict intForKey:@"scale"];
+
+        if ( [dividerDict objectForKey:sym] )
+        {   int div = [dividerDict intForKey:sym];
+            return modulo(angle, 360.0/div) * ((scale) ? div : 1);
+        }
+    }
+    else if ( divider > 1 )
+        return modulo(angle, 360.0/divider) * divider;
+    return angle;
+}
+
 /* calculate main chart
  * modified: 2007-09-03
  */
@@ -496,12 +534,13 @@ typedef enum
         for ( i=0; i<(int)[nodes count]; i++ )
         {   NSString	*node = [nodes objectAtIndex:i];
             float		angle = [nodeDict floatForKey:node];
-            
-        //NSLog(@"%d %@ = %f", i, node, angle);
-        //if (angle == 0.0)
-        //    continue;
+
+            //NSLog(@"%d %@ = %f", i, node, angle);
+            //if (angle == 0.0)
+            //    continue;
             if (rotateAC)
                 angle = standardAngle(angle + rotateAC);
+            angle = [self moduloAngle:angle forObject:node];
             p0 = NSMakePoint(cp.x + radius*RADIUS_2 - radius*(SCALE_MAX+SCALE_MIN), cp.y);
             p1 = NSMakePoint(cp.x + radius*RADIUS_2 + radius*SCALE_MIN, cp.y);
             line = [VLine lineWithPoints:p0 :p1];
@@ -522,8 +561,9 @@ typedef enum
 
             if (rotateAC)
                 angle = standardAngle(angle + rotateAC);
+            angle = [self moduloAngle:angle forObject:planet];
             p0 = NSMakePoint(cp.x + radius*RADIUS_2 - radius*(SCALE_MAX+SCALE_MIN), cp.y);
-            p1 = NSMakePoint(cp.x + radius*RADIUS_2 + radius*SCALE_MIN, cp.y);
+            p1 = NSMakePoint(cp.x + radius*RADIUS_2 + radius*SCALE_MIN,             cp.y);
             line = [VLine lineWithPoints:p0 :p1];
             [line setAngle:-angle withCenter:cp];
             [line setColor:color];
@@ -539,11 +579,11 @@ typedef enum
 
     /* show aspect lines */
     if ( Prefs_ShowAspectGeo && (chartTemplate.components & CHART_ASPECTLINES)	// enabled
-         && !Prefs_ShowDeclination )	// not together with declination
+         && !Prefs_ShowDeclination && divider <= 1 )    // not together with declination and other stuff
     {   AspectLines	*aspectGeo = [AspectLines sharedInstance];
-        id		g;
-        int		objCnt = [planets count];
-        double		objs[objCnt];
+        id      g;
+        int     objCnt = [planets count];
+        double  objs[objCnt];
 
         for ( i=0; i<objCnt; i++ )		// AC, MC, Planets
         {   float	angle = [degreeDict floatForKey:[planets objectAtIndex:i]];
@@ -1102,6 +1142,7 @@ typedef enum
 
         if (rotateAC)
             angle = standardAngle(angle + rotateAC);
+        angle = [self moduloAngle:angle forObject:planet];
         p0 = NSMakePoint(cp.x + radius*RADIUS_3 - radius*(SCALE_MAX+SCALE_MIN), cp.y);
         p1 = NSMakePoint(cp.x + radius*RADIUS_3 + radius*SCALE_MIN, cp.y);
         line = [VLine lineWithPoints:p0 :p1];
@@ -1556,9 +1597,9 @@ typedef enum
 
 - (void)setCompositeLayerEnabled:(BOOL)enabled
 {
-    [[[view layerList] objectAtIndex:ixComposite] setState:enabled];
+    [(LayerObject*)[[view layerList] objectAtIndex:ixComposite] setState:enabled];
     if (ixMaskComposite >= 0 && !Prefs_ACFix)
-        [[[view layerList] objectAtIndex:ixMaskComposite] setState:enabled];
+        [(LayerObject*)[[view layerList] objectAtIndex:ixMaskComposite] setState:enabled];
     [view cache:NSZeroRect];
     [[NSNotificationCenter defaultCenter] postNotificationName:DocLayerListHasChanged object:view];
 }
@@ -1806,6 +1847,8 @@ typedef enum
         [[view document] scale:scale :scale withCenter:NSZeroPoint];
     }
 
+    //[NSBezierPath setDefaultLineWidth:(VHFIsDrawingToScreen() ? 1.0/[view scaleFactor] : 0.1)];   // pointless, because this is not being saved
+
     if (date)
         [(utc = [[date copy] autorelease]) setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
 
@@ -1821,23 +1864,19 @@ typedef enum
     /* get positions
      */
     if ([layerList count] <= 1)		// no way
-    {
-        NSLog(@"Not enough layers (%d) to calculate chart !", [layerList count]);
+    {   NSLog(@"Not enough layers (%d) to calculate chart !", [layerList count]);
         return;
     }
     else if ([layerList count] == 2)	// use defaults
-    {
-        ixRadix = 0;
+    {   ixRadix = 0;
         ixComposite = 1;
     }
     else if ([layerList count] < 5)	// use template and calculate mask defaults
-    {
-        ixRadix = 0;
+    {   ixRadix = 0;
         ixComposite = 1;
     }
     else				// use template and masks
-    {
-        ixMaskRadix = 0;
+    {   ixMaskRadix = 0;
         ixRadix = 1;
         ixMaskComposite = 2;
         ixComposite = 3;
@@ -1887,7 +1926,7 @@ typedef enum
             rotateAC = 180.0 - ac(sideralTime(utc, longitude), latitude);
 
         /* no mask -> calculate basics
-            */
+         */
         {   //maskLayer = (ixMaskRadix) ? [layerList objectAtIndex:ixMaskRadix] : layer;
 
             /* center star */
@@ -1909,12 +1948,12 @@ typedef enum
                                             degreeType:SCALEDEG_360 rotate:rotateAC]];
         }
         /* rotate AC to the left
-            * we create a rotated copy of the mask and turn off the mask
-            */
+         * we create a rotated copy of the mask and turn off the mask
+         */
         if (ixMaskRadix >= 0 && rotateAC)	// rotate Mask
         {   NSArray	*list = [[layerList objectAtIndex:ixMaskRadix] list];
 
-            [[layerList objectAtIndex:ixMaskRadix] setState:0];
+            [(LayerObject*)[layerList objectAtIndex:ixMaskRadix] setState:0];
             for (i=0; i<(int)[list count]; i++)
             {   VGraphic	*g = [[[list objectAtIndex:i] copy] autorelease];
 
@@ -1927,7 +1966,7 @@ typedef enum
             }
         }
         else if (ixMaskRadix >= 0)		// no rotation -> enable mask
-            [[layerList objectAtIndex:ixMaskRadix] setState:1];
+            [(LayerObject*)[layerList objectAtIndex:ixMaskRadix] setState:1];
 
         g = [self horoscopeWithCenter:cp radius:radius tableOrigin:tableOrigin
                              template:template color:[NSColor blackColor]
@@ -2081,7 +2120,7 @@ typedef enum
         if (ixMaskComposite >= 0  && rotateAC)	// rotate Mask
         {   NSArray	*list = [[layerList objectAtIndex:ixMaskComposite] list];
 
-            [[layerList objectAtIndex:ixMaskComposite] setState:0];
+            [(LayerObject*)[layerList objectAtIndex:ixMaskComposite] setState:0];
             for (i=0; i<(int)[list count]; i++)
             {   VGraphic	*g = [[[list objectAtIndex:i] copy] autorelease];
 
@@ -2094,7 +2133,7 @@ typedef enum
             }
         }
         else if (ixMaskComposite >= 0)		// no rotation -> enable mask
-            [[layerList objectAtIndex:ixMaskComposite] setState:1];
+            [(LayerObject*)[layerList objectAtIndex:ixMaskComposite] setState:1];
 
         /* add composite chart */
         g = [self compositeWithCenter:cp radius:radius template:template color:[NSColor blackColor]
@@ -2118,6 +2157,7 @@ typedef enum
 {
     [view release];
     [astroFont release];
+    [dividerDict release];
     [super dealloc];
 }
 
