@@ -141,7 +141,7 @@
  */
 - (void)setClock:(id)sender
 {
-    if ([sender state])	// start clock timer
+    if ([(NSButton*)sender state])  // start clock timer
     {
         if (!timer)
             timer = [NSTimer scheduledTimerWithTimeInterval:60.0
@@ -265,7 +265,7 @@
     NSString		*dateFormat = [[AstroDate sharedInstance] dateFormat];
     NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M"];
 
-    if ([compositeSwitch state])
+    if ([(NSButton*)compositeSwitch state])
     {   int zoneOffset = [cmpZoneField intValue] * 3600;
 
         [date setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:zoneOffset]];
@@ -293,7 +293,7 @@
     {   NSString	*dateFormat = [[AstroDate sharedInstance] dateFormat];
         NSString	*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M"];
 
-        switch ([sender tag])
+        switch ([(NSButton*)sender tag])
         {
             case BUTTONLEFT:	m = ((control) ? -60*24 : -60); break;
             case BUTTONRIGHT:	m = ((control) ?  60*24 :  60);
@@ -356,7 +356,7 @@
 }
 - (NSCalendarDate*)date
 {   NSString        *dateStr = [dateField stringValue], *tzStr = [zoneField stringValue];
-    NSString		*dateFormat = astroDateFormatForString([dateField stringValue]);
+    NSString		*dateFormat = astroDateFormatForString(dateStr);
     NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M %z"];
     NSCalendarDate	*date;
 
@@ -401,7 +401,7 @@
 
 - (BOOL)composite
 {
-    return [compositeSwitch state];
+    return [(NSButton*)compositeSwitch state];
 }
 
 - (void)setCompositeDate:sender
@@ -413,7 +413,7 @@
     {   NSString	*dateFormat = [[AstroDate sharedInstance] dateFormat];
         NSString	*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M"];
 
-        switch ([sender tag])
+        switch ([(NSButton*)sender tag])
         {
             case BUTTONLEFT:	m = ((control) ? -60*24 : -60); break;
             case BUTTONRIGHT:	m = ((control) ?  60*24 :  60);
@@ -495,16 +495,16 @@
     BOOL            setComposite = ([[notification userInfo] intForKey:@"composite"]) ? YES : NO;
 
     if ([event isKindOfClass:[NSDictionary class]])
-    {   int	oldState = [compositeSwitch state];
+    {   int	oldState = [(NSButton*)compositeSwitch state];
 
         if (setComposite && oldState == 0)
-            [compositeSwitch setState:1];	// FIXME: is there a better way to calculate composite ?
-        if ([compositeSwitch state] || setComposite)
+            [(NSButton*)compositeSwitch setState:1];	// FIXME: is there a better way to calculate composite ?
+        if ([(NSButton*)compositeSwitch state] || setComposite)
             [self setCompositeEvent:event]; // calculate composite chart
         else
             [self setEvent:event];          // calculate main chart
         if (setComposite && oldState == 0)
-            [compositeSwitch setState:oldState];
+            [(NSButton*)compositeSwitch setState:oldState];
     }
     else
         NSLog(@"APChart, notification send from object %@, shoult be NSDictionary!", event);
