@@ -43,13 +43,13 @@
 #if USE_TABVIEW	// GNUstep, MAC-OS X
 - (BOOL)canBecomeKeyWindow	{ return YES; }
 
-- awakeFromNib
+- (void)awakeFromNib
 {   static BOOL             awake = NO;
     NSTabViewItem           *item;
     NSNotificationCenter    *notificationCenter = [NSNotificationCenter defaultCenter];
 
     if ( awake )    // we are already awake
-        return self;
+        return;
     awake = YES;
     //[super init];
 
@@ -89,8 +89,6 @@
     [tabView addTabViewItem:item];
     windows[levelCnt] = flowWindow;
     levelCnt++;*/
-
-    return self;
 }
 
 /* delegate: update view of tabViewItem
@@ -222,27 +220,36 @@
             {	if (![NSBundle loadModelNamed:@"APChart" owner:self])
                     NSLog(@"Cannot load APChart interface");
                 windows[level] = chartWindow;
+                views[level] = [windows[level] contentView];
                 [[chartWindow init] setWindow:self];
-                [[chartWindow contentView] retain];	// GNUstep
+                [[chartWindow contentView] retain];             // GNUstep
             }
+            else if ( views[level] && [windows[level] contentView] != views[level] )
+                [windows[level] setContentView:views[level]];   // GNUstep is removing this somewhere
             return chartWindow;
         case AP_MAP:
             if ( !mapWindow )
             {	if (![NSBundle loadModelNamed:@"APMap" owner:self])
                     NSLog(@"Cannot load APMap interface");
                 windows[level] = mapWindow;
+                views[level] = [windows[level] contentView];
                 [[mapWindow init] setWindow:self];
-                [[mapWindow contentView] retain];	// GNUstep
+                [[mapWindow contentView] retain];               // GNUstep
             }
+            else if ( views[level] && [windows[level] contentView] != views[level] )
+                [windows[level] setContentView:views[level]];   // GNUstep is removing this somewhere
             return mapWindow;
         case AP_SEARCH:
             if ( !searchWindow )
             {	if (![NSBundle loadModelNamed:@"APSearch" owner:self])
                     NSLog(@"Cannot load APSearch interface");
                 windows[level] = searchWindow;
+                views[level] = [windows[level] contentView];
                 [[searchWindow init] setWindow:self];
-                [[searchWindow contentView] retain];	// GNUstep
+                [[searchWindow contentView] retain];            // GNUstep
             }
+            else if ( views[level] && [windows[level] contentView] != views[level] )
+                [windows[level] setContentView:views[level]];   // GNUstep is removing this somewhere
             return searchWindow;
         /*case AP_FLOWCHART:
             if ( !flowWindow )
@@ -253,10 +260,17 @@
             }
             return windows[level];*/
         default:
+            if ( level < levelCnt && views[level] && [windows[level] contentView] != views[level] )
+                [windows[level] setContentView:views[level]];   // GNUstep is removing this somewhere
             return (level < levelCnt) ? windows[level] : nil;
     }
+    // FIXME: we never come here, this is future code to replace the switch
+    if ( level >= levelCnt )
+        return nil;
     [[windows[level] init] setWindow:self];
-    [[windows[level] contentView] retain];	// GNUstep
+    [[windows[level] contentView] retain];                      // GNUstep
+    if ( views[level] && [windows[level] contentView] != views[level] )
+        [windows[level] setContentView:views[level]];           // GNUstep is removing this somewhere
     return windows[level];
 }
 
@@ -341,6 +355,7 @@
     int             level = levelCnt;
 
     windows[level] = [panel retain];
+    views[level] = [panel contentView];
     levelCnt ++;
     [panel init];	// ???
     [panel setWindow:self];
