@@ -91,10 +91,12 @@
 
 - (NSString*)version
 {   NSDictionary    *infoDict = [[NSBundle mainBundle] infoDictionary];
-    NSString        *version = [infoDict objectForKey:@"CFBundleVersion"];
+    NSString        *version = [infoDict objectForKey:@"CFBundleShortVersionString"];
 
     if ( ! version )
-        version = [infoDict objectForKey:@"NSVersion"];     // GNUstep
+        version = [infoDict objectForKey:@"CFBundleVersion"];   // Apple, 2nd chance
+    if ( ! version )
+        version = [infoDict objectForKey:@"NSVersion"];         // GNUstep
     return version;
 }
 - (NSString*)compileDate
@@ -102,9 +104,9 @@
     char    date[15];
 
     if ( strlen(compileDate) == 11 )    // Apr 10 2010 -> 2010-04-10
-    {   NSArray *mArray;
-        char    mStr[4];
-        int     m;
+    {   NSArray     *mArray;
+        char        mStr[4];
+        NSUInteger  m;
 
         strncpy(mStr, compileDate, 3); mStr[3] = 0;
         mArray = [NSArray arrayWithObjects:@"Jan", @"Feb", @"Mar", @"Apr", @"May", @"Jun", @"Jul", @"Aug", @"Sep", @"Oct", @"Nov", @"Dec", nil];
@@ -300,7 +302,7 @@ NSString *stringFromDeg(float deg)
  */
 - (void)showWebPage:(id)sender
 {   NSString    *site;
-    int         tag = [sender tag];
+    int         tag = [(NSMenuItem*)sender tag];
 
 	if ([sender isKindOfClass:[NSMatrix class]])
 		tag = [sender selectedTag];
@@ -490,12 +492,20 @@ NSString *stringFromDeg(float deg)
         //else
 #endif
         {
+            if ( [dict objectForKey:@"divider"] )
+                [astroChart setDivider:[dict intForKey:@"divider"]];
+            if ( [dict objectForKey:@"objDivider"] )
+                [astroChart setObjDividers:[dict objectForKey:@"objDivider"]];
             [astroChart radix:[dict objectForKey:@"date"]
                     longitude:[dict floatForKey:@"lon"]
                      latitude:[dict floatForKey:@"lat"]
                          city:[dict objectForKey:@"city"]
                         title:[dict objectForKey:@"name"]
                     composite:[dict objectForKey:@"composite"]];
+            if ( [dict objectForKey:@"divider"] )
+                [astroChart setDivider:1];
+            if ( [dict objectForKey:@"objDivider"] )
+                [astroChart setObjDividers:nil];
         }
     }
     else
