@@ -424,7 +424,7 @@
 
 /* delegate methods
  */
-- (int)browser:(NSBrowser*)sender numberOfRowsInColumn:(int)column
+- (NSInteger)browser:(NSBrowser*)sender numberOfRowsInColumn:(NSInteger)column
 {
     switch (column)
     {
@@ -434,7 +434,7 @@
     return 0;
 }
 
--(void)browser:(NSBrowser*)sender willDisplayCell:(id)cell atRow:(int)row column:(int)column
+-(void)browser:(NSBrowser*)sender willDisplayCell:(id)cell atRow:(NSInteger)row column:(NSInteger)column
 {   NSString	*name;
 
     switch (column)
