@@ -53,7 +53,7 @@
 /* created: 2003-06-22
  * sort event dictionaries by name
  */
-static int sortEventDictionary(id event1, id event2, void *context)
+static NSInteger sortEventDictionary(id event1, id event2, void *context)
 {
     return [(NSString*)[event1 objectForKey:@"name"] compare:[event2 objectForKey:@"name"]];
 }
@@ -678,9 +678,9 @@ static int indexFromType(NSString *typeString)
 /* browser delegate method
  * modified: 2005-07-24
  */
-- (int)browser:(NSBrowser*)sender numberOfRowsInColumn:(int)column
-{   int			folderIx, eventIx;
-    NSArray		*events;
+- (NSInteger)browser:(NSBrowser*)sender numberOfRowsInColumn:(NSInteger)column
+{   int             folderIx, eventIx;
+    NSArray         *events;
     NSDictionary	*subEvents;
 
     switch (column)
@@ -714,10 +714,10 @@ static int indexFromType(NSString *typeString)
 /* browser delegate method
  * modified: 2005-07-24
  */
--(void)browser:(NSBrowser*)sender willDisplayCell:(id)cell atRow:(int)row column:(int)column
-{   int			folderIx, eventIx;
-    NSArray		*events;
-    NSDictionary	*subEvents;
+-(void)browser:(NSBrowser*)sender willDisplayCell:(id)cell atRow:(NSInteger)row column:(NSInteger)column
+{   int             folderIx, eventIx;
+    NSArray         *events;
+    NSDictionary    *subEvents;
 
     switch (column)
     {
