@@ -1,11 +1,12 @@
 /* Ephemeris.m
  * front end object for the Swiss Ephemeris
  *
- * Copyright (C) 1999-2006 by vhf interservice GmbH
+ * Copyright (C) 1999-2011 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2001-09-02
- * modified: 2008-08-23 (-indexForObjectSymbol: added)
+ * modified: 2011-04-24 (-objectSymbols)
+ *           2008-08-23 (-indexForObjectSymbol: added)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -78,6 +79,10 @@ static NSArray *objectSymbols = nil;
 {
     return objectNames;
 }
+- (NSArray*)objectSymbols
+{
+    return objectSymbols;
+}
 
 - (void)setMeanNodes:(BOOL)flag
 {
